pub struct LauncherRoot { /* private fields */ }Trait Implementations
Sourceimpl Debug for LauncherRoot
impl Debug for LauncherRoot
Sourceimpl SimpleComponent for LauncherRoot
impl SimpleComponent for LauncherRoot
Sourcefn update_view(
&self,
widgets: &mut Self::Widgets,
sender: ComponentSender<Self>,
)
fn update_view( &self, widgets: &mut Self::Widgets, sender: ComponentSender<Self>, )
Update the view to represent the updated model.
Sourcetype Init = LauncherRootInit
type Init = LauncherRootInit
The parameter used to initialize the component.
Sourcetype Input = LauncherRootInput
type Input = LauncherRootInput
The message type that the component accepts as inputs.
Sourcetype Output = LauncherRootOutput
type Output = LauncherRootOutput
The message type that the component provides as outputs.
Sourcetype Root = ApplicationWindow
type Root = ApplicationWindow
The top-level widget of the component.
Sourcetype Widgets = LauncherRootWidgets
type Widgets = LauncherRootWidgets
The type that’s used for storing widgets created for this component.
Sourcefn init(
init: Self::Init,
root: Self::Root,
sender: ComponentSender<Self>,
) -> ComponentParts<Self>
fn init( init: Self::Init, root: Self::Root, sender: ComponentSender<Self>, ) -> ComponentParts<Self>
Creates the initial model and view, docking it into the component.
Sourcefn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
fn update(&mut self, message: Self::Input, sender: ComponentSender<Self>)
Processes inputs received by the component.